@@ -63,25 +63,25 @@ struct tracefs_buffer_stat {
 	ssize_t				read_events;
 };
 
-extern const struct tep_format_field common_stacktrace;
+extern const struct tep_format_field tfs_common_stacktrace;
 
-extern pthread_mutex_t toplevel_lock;
+extern pthread_mutex_t tfs_toplevel_lock;
 
 static inline pthread_mutex_t *trace_get_lock(struct tracefs_instance *instance)
 {
-	return instance ? &instance->lock : &toplevel_lock;
+	return instance ? &instance->lock : &tfs_toplevel_lock;
 }
 
-void trace_put_instance(struct tracefs_instance *instance);
-int trace_get_instance(struct tracefs_instance *instance);
+void tfs_put_instance(struct tracefs_instance *instance);
+int tfs_get_instance(struct tracefs_instance *instance);
 
 /* Can be overridden */
 void tracefs_warning(const char *fmt, ...);
 
-char *strstrip(char *str);
-int str_read_file(const char *file, char **buffer, bool warn);
-char *trace_append_file(const char *dir, const char *name);
-char *trace_find_tracing_dir(bool debugfs);
+char *tfs_strstrip(char *str);
+int tfs_str_read_file(const char *file, char **buffer, bool warn);
+char *tfs_append_file(const char *dir, const char *name);
+char *tfs_find_tracing_dir(bool debugfs);
 
 #ifndef ACCESSPERMS
 #define ACCESSPERMS (S_IRWXU|S_IRWXG|S_IRWXO) /* 0777 */
@@ -96,41 +96,43 @@ char *trace_find_tracing_dir(bool debugfs);
 #endif
 
 struct tracefs_options_mask *
-supported_opts_mask(struct tracefs_instance *instance);
+tfs_supported_opts_mask(struct tracefs_instance *instance);
 
 struct tracefs_options_mask *
-enabled_opts_mask(struct tracefs_instance *instance);
+tfs_enabled_opts_mask(struct tracefs_instance *instance);
 
-char **trace_list_create_empty(void);
-int trace_list_pop(char **list);
+char **tfs_list_create_empty(void);
+int tfs_list_pop(char **list);
 
-char *append_string(char *str, const char *delim, const char *add);
-int trace_test_state(int state);
-bool trace_verify_event_field(struct tep_event *event,
-			      const char *field_name,
-			      const struct tep_format_field **ptr_field);
-int trace_append_filter(char **filter, unsigned int *state,
-			unsigned int *open_parens,
-			struct tep_event *event,
-			enum tracefs_filter type,
-			const char *field_name,
-			enum tracefs_compare compare,
-			 const char *val);
+char *tfs_append_string(char *str, const char *delim, const char *add);
+int tfs_test_state(int state);
+bool tfs_verify_event_field(struct tep_event *event,
+			    const char *field_name,
+			    const struct tep_format_field **ptr_field);
+int tfs_append_filter(char **filter, unsigned int *state,
+		      unsigned int *open_parens,
+		      struct tep_event *event,
+		      enum tracefs_filter type,
+		      const char *field_name,
+		      enum tracefs_compare compare,
+		      const char *val);
 
-void *trace_mmap(int fd, struct kbuffer *kbuf);
-void trace_unmap(void *mapping);
-int trace_mmap_load_subbuf(void *mapping, struct kbuffer *kbuf);
-int trace_mmap_read(void *mapping, void *buffer);
+void *tfs_mmap(int fd, struct kbuffer *kbuf);
+void tfs_unmap(void *mapping);
+int tfs_mmap_load_subbuf(void *mapping, struct kbuffer *kbuf);
+int tfs_mmap_read(void *mapping, void *buffer);
 
-struct tracefs_synth *synth_init_from(struct tep_handle *tep,
-				      const char *start_system,
-				      const char *start_event);
+struct tracefs_synth *
+tfs_synth_init_from(struct tep_handle *tep,
+		    const char *start_system,
+		    const char *start_event);
 
 #define HIST_COUNTER_TYPE	(TRACEFS_HIST_KEY_MAX + 100)
-int synth_add_start_field(struct tracefs_synth *synth,
-			  const char *start_field,
-			  const char *name,
-			  enum tracefs_hist_key_type type, int cnt);
+int tfs_synth_add_start_field(struct tracefs_synth *synth,
+			      const char *start_field,
+			      const char *name,
+			      enum tracefs_hist_key_type type,
+			      int cnt);
 
 /* Internal interface for ftrace dynamic events */
 
@@ -145,17 +147,21 @@ struct tracefs_dynevent {
 };
 
 struct tracefs_dynevent *
-dynevent_alloc(enum tracefs_dynevent_type type, const char *system,
-	       const char *event, const char *address, const char *format);
-int dynevent_get_count(unsigned int types, const char *system);
+tfs_dynevent_alloc(enum tracefs_dynevent_type type, const char *system,
+		   const char *event, const char *address, const char *format);
+int tfs_dynevent_get_count(unsigned int types, const char *system);
 
-int trace_load_events(struct tep_handle *tep,
-		      const char *tracing_dir, const char *system);
-int trace_rescan_events(struct tep_handle *tep,
-			const char *tracing_dir, const char *system);
-struct tep_event *get_tep_event(struct tep_handle *tep,
-				const char *system, const char *name);
+int tfs_load_events(struct tep_handle *tep,
+		    const char *tracing_dir,
+		    const char *system);
+int tfs_rescan_events(struct tep_handle *tep,
+		      const char *tracing_dir,
+		      const char *system);
+struct tep_event *
+tfs_get_tep_event(struct tep_handle *tep,
+		  const char *system,
+		  const char *name);
 
-unsigned int quick_hash(const char *str);
+unsigned int tfs_quick_hash(const char *str);
 
 #endif /* _TRACE_FS_LOCAL_H */
